@@ -5,6 +5,6 @@ Freeway is a module for managing file system structures with recursive pattern r
 
 """
 
-from freeway import Freeway
+from .freeway import Freeway
 
-__version__ = '1.0.0'
+__version__ = '0.0.4'
